package models

import (
	"context"
	"errors"
	"io"

	"github.com/docker/docker/api/types"
)

type Container struct {
}

func GetId(containername string) (string, error) {
	containers, err := DockerApi().ContainerList(context.Background(), types.ContainerListOptions{All: true})
	if err != nil {
		return "", err
	}

	for _, container := range containers {

		for _, name := range container.Names {
			if "/"+containername == name {
				return container.ID, nil
			}
		}
	}
	return "", errors.New("Container not found")
}

func ContainerStart(id string) error {
	return DockerApi().ContainerStart(context.Background(), id, types.ContainerStartOptions{})
}

func ContainerStop(id string) error {
	return DockerApi().ContainerStop(context.Background(), id, nil)
}

func ContainerLogs(id string, follow bool) (io.ReadCloser, error) {
	out, err := DockerApi().ContainerLogs(context.Background(), id, types.ContainerLogsOptions{
		ShowStdout: true,
		ShowStderr: true,
		Follow:     follow,
	})
	if err != nil {
		return nil, err
	}
	return out, nil
}
